aboutsummaryrefslogtreecommitdiff
path: root/src/addrs.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/addrs.h')
-rw-r--r--src/addrs.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/src/addrs.h b/src/addrs.h
index dd9f23d..1aca8be 100644
--- a/src/addrs.h
+++ b/src/addrs.h
@@ -14,9 +14,13 @@ extern u8 *dlist_top, *dlist_bot;
extern u16 *dlist_top_lms;
extern u16 *dlist_bot_lms;
/* points to either edit_box or one of the status_boxes[] */
extern u16 *dlist_status_lms;
+/* ANTIC mode of last line, either 2 for GR.0 (edit box showing)
+ or 6 for GR.1 (status box showing) */
+extern u8 *dlist_last_line;
+
/* only one of these (not one per screen) */
extern u8 *edit_box;
@@ -29,5 +33,5 @@ extern u8 *screen_bot_addrs[7];
/* address of last line of _bot, where printing actually happens */
extern u8 *screen_lastlines[7];
-/* bottom 2 lines of the _bot display list for each screen */
-extern u8 *status_boxes[7];
+/* bottom 2 lines, shared by all screens */
+extern u8 *status_box;
@@ -14,9 +14,13 @@ extern u8 *dlist_top, *dlist_bot;
extern u16 *dlist_top_lms;
extern u16 *dlist_bot_lms;
-/* points to either edit_box or one of the status_boxes[] */
+/* points to either edit_box or status_box */
extern u16 *dlist_status_lms;